@@ -14,30 +14,7 @@ import time
 from multiprocessing.connection import Client
 from ipsframework.configobj import ConfigObj
 from ipsframework import platformspec
-
-
-def which(program, alt_paths=None):
-    def is_exe(fpath):
-        return os.path.exists(fpath) and os.access(fpath, os.X_OK)
-
-    fpath, _ = os.path.split(program)
-    if fpath:
-        if is_exe(program):
-            return program
-    else:
-        for path in os.environ["PATH"].split(os.pathsep):
-            exe_file = os.path.join(path, program)
-            if is_exe(exe_file):
-                return exe_file
-
-        # Trust locations in platform file over those in environment path
-        if alt_paths:
-            for path in alt_paths:
-                exe_file = os.path.join(path, program)
-                if is_exe(exe_file):
-                    return exe_file
-
-    return None
+from ipsframework.ipsutil import which
 
 
 class DakotaDynamic:
@@ -53,7 +30,7 @@ class DakotaDynamic:
         self.master_conf = ConfigObj()
         self.restart_file = restart_file
 
-    def run(self):
+    def run(self):  # noqa: C901
         alt_paths = []
 
         """
@@ -109,7 +86,7 @@ class DakotaDynamic:
         # Import environment variables into config file
         # giving precedence to config file definitions in case of duplicates
         for (k, v) in os.environ.items():
-            if k not in list(self.template_conf.keys()) and not any([x in v for x in '{}()$']):
+            if k not in list(self.template_conf.keys()) and not any(x in v for x in '{}()$'):
                 self.template_conf[k] = v
 
         alt_paths.append(self.template_conf['IPS_ROOT'])
@@ -118,7 +95,6 @@ class DakotaDynamic:
 
         new_dakota_config = self.dakota_cfg + '.resolved'
         comp_vars = {}
-#        print self.dakota_conf
         for line in self.dakota_conf:
             if not line:
                 continue
@@ -137,7 +113,6 @@ class DakotaDynamic:
             elif tokens[0] == 'analysis_driver':
                 raw_prog = line.split('=')[1]
                 prog = raw_prog.strip(' "\'')
-#                print raw_prog, prog
                 exec_prog = which(prog, alt_paths)
                 if not exec_prog:
                     raise Exception('Error: analysis driver %s not found in path' % prog)
@@ -213,11 +188,10 @@ IPS_ROOT/bin or IPS_ROOT/framework/src')
         os.environ['IPS_DAKOTA_config'] = os.path.abspath(self.config_template)
         os.environ['IPS_DAKOTA_runid'] = str(os.getpid())
         os.environ['IPS_DAKOTA_SOCKET_ADDRESS'] = sock_address
-        # print '%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%', sock_address
 
-        fd = open(new_dakota_config, 'w')
-        [fd.write('%s\n' % (line)) for line in self.dakota_conf]
-        fd.close()
+        with open(new_dakota_config, 'w') as fd:
+            for line in self.dakota_conf:
+                fd.write('%s\n' % (line))
 
         ips = which('ips.py', alt_paths)
         if not ips:
